/*  
 * Copyright (c) 2010 Ant Kutschera, maxant
 * 
 * This file is part of the maxant PersistentStateMachine.
 * 
 * maxant PersistentStateMachine is free software: you can redistribute it and/or modify
 * it under the terms of the Lesser GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * maxant PersistentStateMachine is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Lesser GNU General Public License for more details.
 * You should have received a copy of the Lesser GNU General Public License
 * along with maxant PersistentStateMachine.  If not, see <http://www.gnu.org/licenses/>.
 */
package uk.co.maxant.demo.scxml.data;

import java.io.Serializable;
import javax.persistence.*;

import uk.co.maxant.demo.scxml.StateMachineDemo;


/**
 * generated using eclipse! but then modified, so that setting the state is done using the state machine.
 */
@Entity
@Table(name="scxml_demo")
@Access(AccessType.PROPERTY) //property based, so that we have a chance to use the state machine for testing transitions
public class SomethingPersistentWithState implements Serializable {

	private static final long serialVersionUID = 1L;

	/**
	 * originally generated field. no annotations, because JPA will use property based access
	 */
	private int idPk;

	/**
	 * originally generated field. but no longer needed, since state is in state machine.
	 */
	//private String state;

	/**
	 * added this field, as it will help with maintaining state.
	 * its NOT persisted!
	 */
	@Transient
	private StateMachineDemo stateMachine;

	/**
	 * added constructor, in order to instantiate state machine.
	 */
    public SomethingPersistentWithState() {
    	stateMachine = new StateMachineDemo();
    }

	/**
	 * originally generated method
	 */
	@Id
	@GeneratedValue(strategy=GenerationType.IDENTITY)
	@Column(name="id_pk")
	public int getIdPk() {
		return this.idPk;
	}

	/**
	 * originally generated method
	 */
	public void setIdPk(int idPk) {
		this.idPk = idPk;
	}

	/**
	 * originally generated method
	 */
	@Column(name="state")
	public String getState() {
		return this.stateMachine.getCurrentState();
	}

    /**
     * added this method to delegate state manipulation to the state machine
     */
    public void triggerBook() {
    	this.stateMachine.triggerBook();
    }

    /**
     * added this method to delegate state manipulation to the state machine
     */
    public void triggerPayment() {
    	this.stateMachine.triggerPayment();
    }

    /**
     * added this method to delegate state manipulation to the state machine
     */
    public void triggerCancel() {
    	this.stateMachine.triggerCancel();
    }

    /**
     * added this method to delegate state manipulation to the state machine
     */
    public void triggerRefund() {
    	this.stateMachine.triggerRefund();
    }

	/**
	 * originally generated method.
	 * note JPA will use property based access because the annotation is on the setter!
	 * private, so that JPA can still call it. but we dont want anyone else using it!
	 */
	@SuppressWarnings("unused")
	private void setState(String state){
		if(!this.stateMachine.getCurrentState().equals(state)){
			this.stateMachine = new StateMachineDemo(state);
		}
	}
	
}