/*  
 * Copyright (c) 2010 Ant Kutschera, maxant
 * 
 * This file is part of the maxant PersistentStateMachine.
 * 
 * maxant PersistentStateMachine is free software: you can redistribute it and/or modify
 * it under the terms of the Lesser GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * maxant PersistentStateMachine is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Lesser GNU General Public License for more details.
 * You should have received a copy of the Lesser GNU General Public License
 * along with maxant PersistentStateMachine.  If not, see <http://www.gnu.org/licenses/>.
 */
package uk.co.maxant.demo.scxml.util;

import java.util.HashMap;
import java.util.Map;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.impl.SimpleLog;

/**
 * allows anyone to get hold of a logger.
 */
public class LogHelper {
	
	private static Map<String, Log> loggers = new HashMap<String, Log>();
	
    /**
     * Creates a new LogHelper object.
     */
    private LogHelper() {
    }

    /**
     * @return  the logger for the class calling this method.
     */
    public synchronized static Log getLog() {
    	String cn = getClassName();
        Log log = loggers.get(cn);
        if(log == null){
        	log = new SimpleLog(cn);
        	loggers.put(cn, log);
        }
        return log;
    }


    /**
     * @return  the name of the class calling this method.
     */
    private static String getClassName() {
        Throwable t = new Throwable();
        StackTraceElement directCaller = t.getStackTrace()[2];

        return directCaller.getClassName();
    }


}
